@@ -73,11 +73,6 @@ void QPainterBackend::setFailed(const QString &reason)
     m_failed = true;
 }
 
-void QPainterBackend::renderCursor(QPainter *painter)
-{
-    Q_UNUSED(painter)
-}
-
 bool QPainterBackend::perScreenRendering() const
 {
     return false;
@@ -163,6 +158,7 @@ qint64 SceneQPainter::paint(QRegion damage, ToplevelList toplevels)
             QRegion updateRegion, validRegion;
             paintScreen(&mask, damage.intersected(geometry), QRegion(), &updateRegion, &validRegion);
             overallUpdate = overallUpdate.united(updateRegion);
+            paintCursor();
 
             m_painter->restore();
             m_painter->end();
@@ -171,6 +167,8 @@ qint64 SceneQPainter::paint(QRegion damage, ToplevelList toplevels)
         m_backend->present(mask, overallUpdate);
     } else {
         m_painter->begin(m_backend->buffer());
+        m_painter->setClipping(true);
+        m_painter->setClipRegion(damage);
         if (m_backend->needsFullRepaint()) {
             mask |= Scene::PAINT_SCREEN_BACKGROUND_FIRST;
             damage = QRegion(0, 0, displayWidth(), displayHeight());
@@ -178,7 +176,7 @@ qint64 SceneQPainter::paint(QRegion damage, ToplevelList toplevels)
         QRegion updateRegion, validRegion;
         paintScreen(&mask, damage, QRegion(), &updateRegion, &validRegion);
 
-        m_backend->renderCursor(m_painter.data());
+        paintCursor();
         m_backend->showOverlay();
 
         m_painter->end();
@@ -197,6 +195,21 @@ void SceneQPainter::paintBackground(QRegion region)
     m_painter->drawRects(region.rects());
 }
 
+void SceneQPainter::paintCursor()
+{
+    if (!kwinApp()->platform()->usesSoftwareCursor()) {
+        return;
+    }
+    const QImage img = kwinApp()->platform()->softwareCursor();
+    if (img.isNull()) {
+        return;
+    }
+    const QPoint cursorPos = Cursor::pos();
+    const QPoint hotspot = kwinApp()->platform()->softwareCursorHotspot();
+    m_painter->drawImage(cursorPos - hotspot, img);
+    kwinApp()->platform()->markCursorAsRendered();
+}
+
 Scene::Window *SceneQPainter::createWindow(Toplevel *toplevel)
 {
     return new SceneQPainter::Window(this, toplevel);
@@ -267,10 +280,10 @@ void SceneQPainter::Window::performPaint(int mask, QRegion region, WindowPaintDa
 
     QPainter *scenePainter = m_scene->painter();
     QPainter *painter = scenePainter;
+    painter->save();
     painter->setClipRegion(region);
     painter->setClipping(true);
 
-    painter->save();
     painter->translate(x(), y());
     if (mask & PAINT_WINDOW_TRANSFORMED) {
         painter->translate(data.xTranslation(), data.yTranslation());
@@ -317,9 +330,6 @@ void SceneQPainter::Window::performPaint(int mask, QRegion region, WindowPaintDa
     }
 
     painter->restore();
-
-    painter->setClipRegion(QRegion());
-    painter->setClipping(false);
 }
 
 void SceneQPainter::Window::renderShadow(QPainter* painter)
